@@ -1,7 +1,7 @@
 import numpy as np
-from metric import metric
+from .metric import Metric
 
-class Accuracy(metric.Metric):
+class Accuracy(Metric):
     """ Accuracy.
 
     Args:
@@ -31,4 +31,4 @@ class Accuracy(metric.Metric):
         Returns:
             Accuracy as a percentage
         """
-        return 100 * self.correct/max(self.total, 1)
\ No newline at end of file
+        return 100 * self.correct/max(self.total, 1)
