@@ -1,8 +1,8 @@
 import numpy as np
-from metric import metric
+from .metric import Metric
 
 
-class L1Error(metric.Metric):
+class L1Error(Metric):
     """L1 error.
 
     Args:
@@ -44,4 +44,4 @@ class L1Error(metric.Metric):
         if self.per_pixel:
             return self.l1_sum / max(self.n, 1)
         else:
-            return self.l1_sum
\ No newline at end of file
+            return self.l1_sum
